@@ -1,9 +1,13 @@
 from rlh.handlers import (
     RedisLogHandler,
     RedisStreamLogHandler,
+    RedisPubSubLogHandler,
 )
 
 __all__ = [
     "RedisLogHandler",
     "RedisStreamLogHandler",
+    "RedisPubSubLogHandler",
 ]
+
+__version__ = "1.1.0"
